.. Forest Guided Clustering documentation master file, created by
   sphinx-quickstart on Thu Dec  9 16:39:21 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

*Forest-Guided Clustering* - Shedding light into the Random Forest Black Box 
==============================================================================

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- LINK INTRODUCTION START -->
   :end-before: <!-- LINK INTRODUCTION END -->


.. toctree::
   :maxdepth: 1
   :caption: 🚀 GETTING STARTED

   _getting_started/installation.rst
   _getting_started/basic_usage.rst


.. toctree::
   :maxdepth: 1
   :caption: 📚 TUTORIALS

   _tutorials/introduction_to_FGC_use_cases
   _tutorials/introduction_to_FGC_comparing_FGC_to_FI
   _tutorials/special_case_inference_with_FGC
   _tutorials/special_case_impact_of_model_complexity_on_FGC
   _tutorials/special_case_big_data_with_FGC


.. toctree::
   :maxdepth: 2
   :caption: 🧩 API DOCUMENTATION:

   fgclustering.rst


🤝 Contributing
------------------

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- LINK CONTRIBUTION START -->
   :end-before: <!-- LINK CONTRIBUTION END -->

📝 How to cite
----------------

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- LINK CITE START -->
   :end-before: <!-- LINK CITE END -->

🛡️ License
-------------

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- LINK LICENSE START -->
   :end-before: <!-- LINK LICENSE END -->